# coding: utf-8

"""
    Operation Manager Agent API

    Interact with deployed Cloud Computing resources via API.

    OpenAPI spec version: 0.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Execution(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, op_id=None, execution_id=None, progress=None, info=None):
        """
        Execution - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'op_id': 'int',
            'execution_id': 'str',
            'progress': 'float',
            'info': 'str'
        }

        self.attribute_map = {
            'op_id': 'op_id',
            'execution_id': 'execution_id',
            'progress': 'progress',
            'info': 'info'
        }

        self._op_id = op_id
        self._execution_id = execution_id
        self._progress = progress
        self._info = info

    @property
    def op_id(self):
        """
        Gets the op_id of this Execution.
        Unique identifier representing a specific op

        :return: The op_id of this Execution.
        :rtype: int
        """
        return self._op_id

    @op_id.setter
    def op_id(self, op_id):
        """
        Sets the op_id of this Execution.
        Unique identifier representing a specific op

        :param op_id: The op_id of this Execution.
        :type: int
        """

        self._op_id = op_id

    @property
    def execution_id(self):
        """
        Gets the execution_id of this Execution.
        Id of the execution (application specific)

        :return: The execution_id of this Execution.
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """
        Sets the execution_id of this Execution.
        Id of the execution (application specific)

        :param execution_id: The execution_id of this Execution.
        :type: str
        """

        self._execution_id = execution_id

    @property
    def progress(self):
        """
        Gets the progress of this Execution.
        percentage representing the progress of the execution

        :return: The progress of this Execution.
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """
        Sets the progress of this Execution.
        percentage representing the progress of the execution

        :param progress: The progress of this Execution.
        :type: float
        """

        self._progress = progress

    @property
    def info(self):
        """
        Gets the info of this Execution.
        Formatted JSON information about the progress of the op

        :return: The info of this Execution.
        :rtype: str
        """
        return self._info

    @info.setter
    def info(self, info):
        """
        Sets the info of this Execution.
        Formatted JSON information about the progress of the op

        :param info: The info of this Execution.
        :type: str
        """

        self._info = info

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .cluster_definitions_api import ClusterDefinitionsApi
from .credentials_api import CredentialsApi
from .host_definitions_api import HostDefinitionsApi
from .users_api import UsersApi



# coding: utf-8

"""
    Appliance Registry API

    Store appliances with the Appliance Registry API.

    OpenAPI spec version: 0.1.13
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Site(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, type=None, contact_url=None, appliances=None):
        """
        Site - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'contact_url': 'str',
            'appliances': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'contact_url': 'contact_url',
            'appliances': 'appliances'
        }

        self._name = name
        self._type = type
        self._contact_url = contact_url
        self._appliances = appliances

    @property
    def name(self):
        """
        Gets the name of this Site.
        Name of the site

        :return: The name of this Site.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Site.
        Name of the site

        :param name: The name of this Site.
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this Site.
        Type of the site (e.g. openstack)

        :return: The type of this Site.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Site.
        Type of the site (e.g. openstack)

        :param type: The type of this Site.
        :type: str
        """

        self._type = type

    @property
    def contact_url(self):
        """
        Gets the contact_url of this Site.
        Contact URL of the site

        :return: The contact_url of this Site.
        :rtype: str
        """
        return self._contact_url

    @contact_url.setter
    def contact_url(self, contact_url):
        """
        Sets the contact_url of this Site.
        Contact URL of the site

        :param contact_url: The contact_url of this Site.
        :type: str
        """

        self._contact_url = contact_url

    @property
    def appliances(self):
        """
        Gets the appliances of this Site.


        :return: The appliances of this Site.
        :rtype: list[str]
        """
        return self._appliances

    @appliances.setter
    def appliances(self, appliances):
        """
        Sets the appliances of this Site.


        :param appliances: The appliances of this Site.
        :type: list[str]
        """

        self._appliances = appliances

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class User(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, username=None, first_name=None, last_name=None, email=None, credentials=None, clusters=None, is_staff=None, is_superuser=None, is_active=None, date_joined=None):
        """
        User - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'username': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str',
            'credentials': 'list[int]',
            'clusters': 'list[int]',
            'is_staff': 'int',
            'is_superuser': 'int',
            'is_active': 'int',
            'date_joined': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'username': 'username',
            'first_name': 'first_name',
            'last_name': 'last_name',
            'email': 'email',
            'credentials': 'credentials',
            'clusters': 'clusters',
            'is_staff': 'is_staff',
            'is_superuser': 'is_superuser',
            'is_active': 'is_active',
            'date_joined': 'date_joined'
        }

        self._id = id
        self._username = username
        self._first_name = first_name
        self._last_name = last_name
        self._email = email
        self._credentials = credentials
        self._clusters = clusters
        self._is_staff = is_staff
        self._is_superuser = is_superuser
        self._is_active = is_active
        self._date_joined = date_joined


    @property
    def id(self):
        """
        Gets the id of this User.
        Unique identifier representing a specific user

        :return: The id of this User.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this User.
        Unique identifier representing a specific user

        :param id: The id of this User.
        :type: int
        """

        self._id = id

    @property
    def username(self):
        """
        Gets the username of this User.
        Name given to the user

        :return: The username of this User.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this User.
        Name given to the user

        :param username: The username of this User.
        :type: str
        """

        self._username = username

    @property
    def first_name(self):
        """
        Gets the first_name of this User.
        First name of the user

        :return: The first_name of this User.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this User.
        First name of the user

        :param first_name: The first_name of this User.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this User.
        Last name of the user

        :return: The last_name of this User.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this User.
        Last name of the user

        :param last_name: The last_name of this User.
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this User.
        Email of the user

        :return: The email of this User.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this User.
        Email of the user

        :param email: The email of this User.
        :type: str
        """

        self._email = email

    @property
    def credentials(self):
        """
        Gets the credentials of this User.
        Array of the credentials IDs of the user

        :return: The credentials of this User.
        :rtype: list[int]
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this User.
        Array of the credentials IDs of the user

        :param credentials: The credentials of this User.
        :type: list[int]
        """

        self._credentials = credentials

    @property
    def clusters(self):
        """
        Gets the clusters of this User.
        Array of the clusters IDs of the user

        :return: The clusters of this User.
        :rtype: list[int]
        """
        return self._clusters

    @clusters.setter
    def clusters(self, clusters):
        """
        Sets the clusters of this User.
        Array of the clusters IDs of the user

        :param clusters: The clusters of this User.
        :type: list[int]
        """

        self._clusters = clusters

    @property
    def is_staff(self):
        """
        Gets the is_staff of this User.
        Boolean stating wether the user is a staff member or not

        :return: The is_staff of this User.
        :rtype: int
        """
        return self._is_staff

    @is_staff.setter
    def is_staff(self, is_staff):
        """
        Sets the is_staff of this User.
        Boolean stating wether the user is a staff member or not

        :param is_staff: The is_staff of this User.
        :type: int
        """

        self._is_staff = is_staff

    @property
    def is_superuser(self):
        """
        Gets the is_superuser of this User.
        Boolean stating wether the user is a superuser or not

        :return: The is_superuser of this User.
        :rtype: int
        """
        return self._is_superuser

    @is_superuser.setter
    def is_superuser(self, is_superuser):
        """
        Sets the is_superuser of this User.
        Boolean stating wether the user is a superuser or not

        :param is_superuser: The is_superuser of this User.
        :type: int
        """

        self._is_superuser = is_superuser

    @property
    def is_active(self):
        """
        Gets the is_active of this User.
        Boolean stating wether the user is active or not

        :return: The is_active of this User.
        :rtype: int
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this User.
        Boolean stating wether the user is active or not

        :param is_active: The is_active of this User.
        :type: int
        """

        self._is_active = is_active

    @property
    def date_joined(self):
        """
        Gets the date_joined of this User.
        Date and time of creation of the user

        :return: The date_joined of this User.
        :rtype: datetime
        """
        return self._date_joined

    @date_joined.setter
    def date_joined(self, date_joined):
        """
        Sets the date_joined of this User.
        Date and time of creation of the user

        :param date_joined: The date_joined of this User.
        :type: datetime
        """

        self._date_joined = date_joined

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import json
import os.path
from os.path import expanduser


home = expanduser("~")
# configuration_file_path = "%s/dibbs.json" % (home)
configuration_file_path = "/etc/dibbs/dibbs.json"

class Configuration(object):

    def __init__(self):
        self._reload_config()
        pass

    def _reload_config(self):
        self.configuration = {
            "address": "127.0.0.1"
        }
        if os.path.exists(configuration_file_path):
            with open(configuration_file_path) as data_file:
                try:
                    self.configuration = json.load(data_file)
                except:
                    print("""Found a configuration in "%s", but I could not understand it.""" % (configuration_file_path))

    def get_ip_address(self):
        return self.configuration["address"]

    def get_appliance_registry_url(self):
        self._reload_config()
        return "http://%s:8003" % (self.get_ip_address())

    def get_operation_registry_url(self):
        self._reload_config()
        return "http://%s:8000" % (self.get_ip_address())

    def get_operation_manager_url(self):
        self._reload_config()
        return "http://%s:8001" % (self.get_ip_address())

    def get_resource_manager_url(self):
        self._reload_config()
        return "http://%s:8002" % (self.get_ip_address())

    def get_operation_manager_agent_url(self):
        self._reload_config()
        return "http://%s:8011" % (self.get_ip_address())

    def get_resource_manager_agent_url(self):
        self._reload_config()
        return "http://%s:8012" % (self.get_ip_address())

    def get_central_authentication_service_url(self):
        self._reload_config()
        return "http://%s:7000" % (self.get_ip_address())



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Credential(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, site_name=None, name=None, user=None, credentials=None):
        """
        Credential - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'site_name': 'str',
            'name': 'str',
            'user': 'int',
            'credentials': 'str'
        }

        self.attribute_map = {
            'site_name': 'site_name',
            'name': 'name',
            'user': 'user',
            'credentials': 'credentials'
        }

        self._site_name = site_name
        self._name = name
        self._user = user
        self._credentials = credentials


    @property
    def site_name(self):
        """
        Gets the site_name of this Credential.
        Name of the site

        :return: The site_name of this Credential.
        :rtype: str
        """
        return self._site_name

    @site_name.setter
    def site_name(self, site_name):
        """
        Sets the site_name of this Credential.
        Name of the site

        :param site_name: The site_name of this Credential.
        :type: str
        """
        if site_name is None:
            raise ValueError("Invalid value for `site_name`, must not be `None`")

        self._site_name = site_name

    @property
    def name(self):
        """
        Gets the name of this Credential.
        Name of the credential

        :return: The name of this Credential.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Credential.
        Name of the credential

        :param name: The name of this Credential.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def user(self):
        """
        Gets the user of this Credential.
        ID of the user

        :return: The user of this Credential.
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Credential.
        ID of the user

        :param user: The user of this Credential.
        :type: int
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")

        self._user = user

    @property
    def credentials(self):
        """
        Gets the credentials of this Credential.
        Encrypted credentials (JSON format encrypted)

        :return: The credentials of this Credential.
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this Credential.
        Encrypted credentials (JSON format encrypted)

        :param credentials: The credentials of this Credential.
        :type: str
        """
        if credentials is None:
            raise ValueError("Invalid value for `credentials`, must not be `None`")

        self._credentials = credentials

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into sdk package
from .models.cluster import Cluster
from .models.cluster_post import ClusterPost
from .models.credential import Credential
from .models.credential_patch import CredentialPatch
from .models.credential_post import CredentialPost
from .models.credentials import Credentials
from .models.error import Error
from .models.hosts import Hosts
from .models.hosts_post import HostsPost
from .models.public_key import PublicKey
from .models.temporary_account_credential import TemporaryAccountCredential
from .models.token_resp import TokenResp
from .models.user import User
from .models.user_patch import UserPatch
from .models.user_post import UserPost

# import apis into sdk package
from .apis.cluster_definitions_api import ClusterDefinitionsApi
from .apis.credentials_api import CredentialsApi
from .apis.host_definitions_api import HostDefinitionsApi
from .apis.users_api import UsersApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class UserPatch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, username=None, password=None, first_name=None, last_name=None, email=None):
        """
        UserPatch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'username': 'str',
            'password': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str'
        }

        self.attribute_map = {
            'username': 'username',
            'password': 'password',
            'first_name': 'first_name',
            'last_name': 'last_name',
            'email': 'email'
        }

        self._username = username
        self._password = password
        self._first_name = first_name
        self._last_name = last_name
        self._email = email


    @property
    def username(self):
        """
        Gets the username of this UserPatch.
        Name given to the user

        :return: The username of this UserPatch.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this UserPatch.
        Name given to the user

        :param username: The username of this UserPatch.
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """
        Gets the password of this UserPatch.
        Password of the user

        :return: The password of this UserPatch.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this UserPatch.
        Password of the user

        :param password: The password of this UserPatch.
        :type: str
        """

        self._password = password

    @property
    def first_name(self):
        """
        Gets the first_name of this UserPatch.
        First name of the user

        :return: The first_name of this UserPatch.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this UserPatch.
        First name of the user

        :param first_name: The first_name of this UserPatch.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this UserPatch.
        Last name of the user

        :return: The last_name of this UserPatch.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this UserPatch.
        Last name of the user

        :param last_name: The last_name of this UserPatch.
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this UserPatch.
        Email of the user

        :return: The email of this UserPatch.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UserPatch.
        Email of the user

        :param email: The email of this UserPatch.
        :type: str
        """

        self._email = email

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Appliance Registry API

    Store appliances with the Appliance Registry API.

    OpenAPI spec version: 0.1.13
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class User(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, username=None, operation_definitions=None, definition=None):
        """
        User - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'username': 'str',
            'operation_definitions': 'list[int]',
            'definition': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'username': 'username',
            'operation_definitions': 'operation_definitions',
            'definition': 'definition'
        }

        self._id = id
        self._username = username
        self._operation_definitions = operation_definitions
        self._definition = definition

    @property
    def id(self):
        """
        Gets the id of this User.
        Unique identifier representing a specific user

        :return: The id of this User.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this User.
        Unique identifier representing a specific user

        :param id: The id of this User.
        :type: int
        """

        self._id = id

    @property
    def username(self):
        """
        Gets the username of this User.
        Name given to the user.

        :return: The username of this User.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this User.
        Name given to the user.

        :param username: The username of this User.
        :type: str
        """

        self._username = username

    @property
    def operation_definitions(self):
        """
        Gets the operation_definitions of this User.
        Array of IDs of all the process descriptions created by the user

        :return: The operation_definitions of this User.
        :rtype: list[int]
        """
        return self._operation_definitions

    @operation_definitions.setter
    def operation_definitions(self, operation_definitions):
        """
        Sets the operation_definitions of this User.
        Array of IDs of all the process descriptions created by the user

        :param operation_definitions: The operation_definitions of this User.
        :type: list[int]
        """

        self._operation_definitions = operation_definitions

    @property
    def definition(self):
        """
        Gets the definition of this User.
        JSON-formatted string containing all the information required to start the process

        :return: The definition of this User.
        :rtype: str
        """
        return self._definition

    @definition.setter
    def definition(self, definition):
        """
        Sets the definition of this User.
        JSON-formatted string containing all the information required to start the process

        :param definition: The definition of this User.
        :type: str
        """

        self._definition = definition

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# Configure Swagger Python client

# Remove basic auth from the configuration.py file in the client package
# Import Settings from settings and set the host default as Settings().***
# Add this file to the client package


def configure_auth(value, prefix='Token', label='Authorization'):
    import configuration
    config = configuration.Configuration()
    config.api_key_prefix.update({label: prefix})
    config.api_key.update({label: value})


def configure_auth_basic(username, password):
    from apis.ops_api import OpsApi

    credentials = {"username": username, "password": password}

    ret = OpsApi().api_token_auth_post(data=credentials)

    token = ret.token

    configure_auth(token)


def configure_host(value):
    import configuration
    config = configuration.Configuration()
    config.host = value



# coding: utf-8

"""
    Appliance Registry API

    Store appliances with the Appliance Registry API.

    OpenAPI spec version: 0.1.13
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into sdk package
from .models.action import Action
from .models.action_patch import ActionPatch
from .models.action_post import ActionPost
from .models.appliance import Appliance
from .models.appliance_implementation import ApplianceImplementation
from .models.appliance_implementation_patch import ApplianceImplementationPatch
from .models.appliance_implementation_post import ApplianceImplementationPost
from .models.appliance_patch import AppliancePatch
from .models.appliance_post import AppliancePost
from .models.credentials import Credentials
from .models.error import Error
from .models.script import Script
from .models.script_patch import ScriptPatch
from .models.script_post import ScriptPost
from .models.site import Site
from .models.site_patch import SitePatch
from .models.site_post import SitePost
from .models.token_resp import TokenResp
from .models.user import User

# import apis into sdk package
from .apis.actions_api import ActionsApi
from .apis.appliance_implementations_api import ApplianceImplementationsApi
from .apis.appliances_api import AppliancesApi
from .apis.scripts_api import ScriptsApi
from .apis.sites_api import SitesApi
from .apis.users_api import UsersApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



import base64


def configure_basic_authentication(swagger_client, username, password):
    authentication_string = "%s:%s" % (username, password)
    base64_authentication_string = base64.b64encode(bytes(authentication_string))
    header_key = "Authorization"
    header_value = "Basic %s" % (base64_authentication_string, )
    swagger_client.api_client.default_headers[header_key] = header_value



from __future__ import absolute_import

# import apis into api package
from .actions_api import ActionsApi
from .appliance_implementations_api import ApplianceImplementationsApi
from .appliances_api import AppliancesApi
from .scripts_api import ScriptsApi
from .sites_api import SitesApi
from .users_api import UsersApi



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class HostDefinitionsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def hosts_get(self, **kwargs):
        """
        Get the list of all the Host definitions registered.
        Get the list of all the Host definitions registered. No authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[Hosts]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_get_with_http_info(**kwargs)
        else:
            (data) = self.hosts_get_with_http_info(**kwargs)
            return data

    def hosts_get_with_http_info(self, **kwargs):
        """
        Get the list of all the Host definitions registered.
        Get the list of all the Host definitions registered. No authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[Hosts]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_get" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        resource_path = '/hosts/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Hosts]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            _request_timeout=params.get('_request_timeout'),
                                            collection_formats=collection_formats)

    def hosts_id_delete(self, id, **kwargs):
        """
        Delete an existing host definition.
        Delete an already existing host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_id_delete(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: Id of the host (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_id_delete_with_http_info(id, **kwargs)
        else:
            (data) = self.hosts_id_delete_with_http_info(id, **kwargs)
            return data

    def hosts_id_delete_with_http_info(self, id, **kwargs):
        """
        Delete an existing host definition.
        Delete an already existing host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_id_delete_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: Id of the host (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `hosts_id_delete`")

        if 'id' in params and params['id'] < 0.0:
            raise ValueError("Invalid value for parameter `id` when calling `hosts_id_delete`, must be a value greater than or equal to `0.0`")

        collection_formats = {}

        resource_path = '/hosts/{id}/'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            _request_timeout=params.get('_request_timeout'),
                                            collection_formats=collection_formats)

    def hosts_id_get(self, id, **kwargs):
        """
        Get a single host definition.
        Get a single host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_id_get(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: Id of the host description (required)
        :return: Hosts
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_id_get_with_http_info(id, **kwargs)
        else:
            (data) = self.hosts_id_get_with_http_info(id, **kwargs)
            return data

    def hosts_id_get_with_http_info(self, id, **kwargs):
        """
        Get a single host definition.
        Get a single host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_id_get_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int id: Id of the host description (required)
        :return: Hosts
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `hosts_id_get`")

        if 'id' in params and params['id'] < 0.0:
            raise ValueError("Invalid value for parameter `id` when calling `hosts_id_get`, must be a value greater than or equal to `0.0`")

        collection_formats = {}

        resource_path = '/hosts/{id}/'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Hosts',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            _request_timeout=params.get('_request_timeout'),
                                            collection_formats=collection_formats)

    def hosts_post(self, data, **kwargs):
        """
        Add a new host definition.
        Add a new host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_post(data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HostsPost data: host definition (required)
        :return: Hosts
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_post_with_http_info(data, **kwargs)
        else:
            (data) = self.hosts_post_with_http_info(data, **kwargs)
            return data

    def hosts_post_with_http_info(self, data, **kwargs):
        """
        Add a new host definition.
        Add a new host definition. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_post_with_http_info(data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HostsPost data: host definition (required)
        :return: Hosts
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data' is set
        if ('data' not in params) or (params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `hosts_post`")


        collection_formats = {}

        resource_path = '/hosts/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Hosts',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'),
                                            _preload_content=params.get('_preload_content', True),
                                            _request_timeout=params.get('_request_timeout'),
                                            collection_formats=collection_formats)



# coding: utf-8

"""
    Resource manager API

    Manage Cloud Computing resources via API.

    OpenAPI spec version: 0.1.12
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Cluster(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, name=None, uuid=None, hints=None, credential=None, public_key=None, status=None, hosts_ids=None, targeted_slaves_count=None, current_slaves_count=None, hosts_ips=None, master_node_id=None, master_node_ip=None, user_id=None, appliance=None, appliance_impl=None):
        """
        Cluster - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'name': 'str',
            'uuid': 'str',
            'hints': 'str',
            'credential': 'str',
            'public_key': 'str',
            'status': 'str',
            'hosts_ids': 'list[str]',
            'targeted_slaves_count': 'int',
            'current_slaves_count': 'int',
            'hosts_ips': 'list[str]',
            'master_node_id': 'int',
            'master_node_ip': 'str',
            'user_id': 'int',
            'appliance': 'str',
            'appliance_impl': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'uuid': 'uuid',
            'hints': 'hints',
            'credential': 'credential',
            'public_key': 'public_key',
            'status': 'status',
            'hosts_ids': 'hosts_ids',
            'targeted_slaves_count': 'targeted_slaves_count',
            'current_slaves_count': 'current_slaves_count',
            'hosts_ips': 'hosts_ips',
            'master_node_id': 'master_node_id',
            'master_node_ip': 'master_node_ip',
            'user_id': 'user_id',
            'appliance': 'appliance',
            'appliance_impl': 'appliance_impl'
        }

        self._id = id
        self._name = name
        self._uuid = uuid
        self._hints = hints
        self._credential = credential
        self._public_key = public_key
        self._status = status
        self._hosts_ids = hosts_ids
        self._targeted_slaves_count = targeted_slaves_count
        self._current_slaves_count = current_slaves_count
        self._hosts_ips = hosts_ips
        self._master_node_id = master_node_id
        self._master_node_ip = master_node_ip
        self._user_id = user_id
        self._appliance = appliance
        self._appliance_impl = appliance_impl


    @property
    def id(self):
        """
        Gets the id of this Cluster.
        Unique ID of the cluster

        :return: The id of this Cluster.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Cluster.
        Unique ID of the cluster

        :param id: The id of this Cluster.
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Cluster.
        Name given to the cluster

        :return: The name of this Cluster.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Cluster.
        Name given to the cluster

        :param name: The name of this Cluster.
        :type: str
        """

        self._name = name

    @property
    def uuid(self):
        """
        Gets the uuid of this Cluster.
        Internal UUID given to the cluster

        :return: The uuid of this Cluster.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this Cluster.
        Internal UUID given to the cluster

        :param uuid: The uuid of this Cluster.
        :type: str
        """

        self._uuid = uuid

    @property
    def hints(self):
        """
        Gets the hints of this Cluster.
        hints that will be used to select the infrastructure that will host cluster's nodes

        :return: The hints of this Cluster.
        :rtype: str
        """
        return self._hints

    @hints.setter
    def hints(self, hints):
        """
        Sets the hints of this Cluster.
        hints that will be used to select the infrastructure that will host cluster's nodes

        :param hints: The hints of this Cluster.
        :type: str
        """

        self._hints = hints

    @property
    def credential(self):
        """
        Gets the credential of this Cluster.
        hints that will be used to select the infrastructure that will host cluster's nodes

        :return: The credential of this Cluster.
        :rtype: str
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """
        Sets the credential of this Cluster.
        hints that will be used to select the infrastructure that will host cluster's nodes

        :param credential: The credential of this Cluster.
        :type: str
        """

        self._credential = credential

    @property
    def public_key(self):
        """
        Gets the public_key of this Cluster.
        Public key used to identify nodes of the cluster

        :return: The public_key of this Cluster.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this Cluster.
        Public key used to identify nodes of the cluster

        :param public_key: The public_key of this Cluster.
        :type: str
        """

        self._public_key = public_key

    @property
    def status(self):
        """
        Gets the status of this Cluster.
        Status of the cluster

        :return: The status of this Cluster.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Cluster.
        Status of the cluster

        :param status: The status of this Cluster.
        :type: str
        """

        self._status = status

    @property
    def hosts_ids(self):
        """
        Gets the hosts_ids of this Cluster.
        IDs of nodes of the cluster (can be null)

        :return: The hosts_ids of this Cluster.
        :rtype: list[str]
        """
        return self._hosts_ids

    @hosts_ids.setter
    def hosts_ids(self, hosts_ids):
        """
        Sets the hosts_ids of this Cluster.
        IDs of nodes of the cluster (can be null)

        :param hosts_ids: The hosts_ids of this Cluster.
        :type: list[str]
        """

        self._hosts_ids = hosts_ids

    @property
    def targeted_slaves_count(self):
        """
        Gets the targeted_slaves_count of this Cluster.
        targeted number of slaves in the cluster

        :return: The targeted_slaves_count of this Cluster.
        :rtype: int
        """
        return self._targeted_slaves_count

    @targeted_slaves_count.setter
    def targeted_slaves_count(self, targeted_slaves_count):
        """
        Sets the targeted_slaves_count of this Cluster.
        targeted number of slaves in the cluster

        :param targeted_slaves_count: The targeted_slaves_count of this Cluster.
        :type: int
        """

        self._targeted_slaves_count = targeted_slaves_count

    @property
    def current_slaves_count(self):
        """
        Gets the current_slaves_count of this Cluster.
        current number of slaves in the cluster

        :return: The current_slaves_count of this Cluster.
        :rtype: int
        """
        return self._current_slaves_count

    @current_slaves_count.setter
    def current_slaves_count(self, current_slaves_count):
        """
        Sets the current_slaves_count of this Cluster.
        current number of slaves in the cluster

        :param current_slaves_count: The current_slaves_count of this Cluster.
        :type: int
        """

        self._current_slaves_count = current_slaves_count

    @property
    def hosts_ips(self):
        """
        Gets the hosts_ips of this Cluster.
        IP addresses of nodes of the cluster (can be null)

        :return: The hosts_ips of this Cluster.
        :rtype: list[str]
        """
        return self._hosts_ips

    @hosts_ips.setter
    def hosts_ips(self, hosts_ips):
        """
        Sets the hosts_ips of this Cluster.
        IP addresses of nodes of the cluster (can be null)

        :param hosts_ips: The hosts_ips of this Cluster.
        :type: list[str]
        """

        self._hosts_ips = hosts_ips

    @property
    def master_node_id(self):
        """
        Gets the master_node_id of this Cluster.
        ID of the master node of the cluster (can be null)

        :return: The master_node_id of this Cluster.
        :rtype: int
        """
        return self._master_node_id

    @master_node_id.setter
    def master_node_id(self, master_node_id):
        """
        Sets the master_node_id of this Cluster.
        ID of the master node of the cluster (can be null)

        :param master_node_id: The master_node_id of this Cluster.
        :type: int
        """

        self._master_node_id = master_node_id

    @property
    def master_node_ip(self):
        """
        Gets the master_node_ip of this Cluster.
        IP address of the master node of the cluster (can be null)

        :return: The master_node_ip of this Cluster.
        :rtype: str
        """
        return self._master_node_ip

    @master_node_ip.setter
    def master_node_ip(self, master_node_ip):
        """
        Sets the master_node_ip of this Cluster.
        IP address of the master node of the cluster (can be null)

        :param master_node_ip: The master_node_ip of this Cluster.
        :type: str
        """

        self._master_node_ip = master_node_ip

    @property
    def user_id(self):
        """
        Gets the user_id of this Cluster.
        ID of the user that created the cluster

        :return: The user_id of this Cluster.
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this Cluster.
        ID of the user that created the cluster

        :param user_id: The user_id of this Cluster.
        :type: int
        """

        self._user_id = user_id

    @property
    def appliance(self):
        """
        Gets the appliance of this Cluster.
        Appliance of the cluster

        :return: The appliance of this Cluster.
        :rtype: str
        """
        return self._appliance

    @appliance.setter
    def appliance(self, appliance):
        """
        Sets the appliance of this Cluster.
        Appliance of the cluster

        :param appliance: The appliance of this Cluster.
        :type: str
        """

        self._appliance = appliance

    @property
    def appliance_impl(self):
        """
        Gets the appliance_impl of this Cluster.
        Appliance of the cluster

        :return: The appliance_impl of this Cluster.
        :rtype: str
        """
        return self._appliance_impl

    @appliance_impl.setter
    def appliance_impl(self, appliance_impl):
        """
        Sets the appliance_impl of this Cluster.
        Appliance of the cluster

        :param appliance_impl: The appliance_impl of this Cluster.
        :type: str
        """

        self._appliance_impl = appliance_impl

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Operation Registry API

    Register operations with the Operation Registry API.

    OpenAPI spec version: 0.1.9
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class OperationsPatch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, logo_url=None, description=None, string_parameters=None, file_parameters=None):
        """
        OperationsPatch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'logo_url': 'str',
            'description': 'str',
            'string_parameters': 'str',
            'file_parameters': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'logo_url': 'logo_url',
            'description': 'description',
            'string_parameters': 'string_parameters',
            'file_parameters': 'file_parameters'
        }

        self._name = name
        self._logo_url = logo_url
        self._description = description
        self._string_parameters = string_parameters
        self._file_parameters = file_parameters

    @property
    def name(self):
        """
        Gets the name of this OperationsPatch.
        Name given to the process definition

        :return: The name of this OperationsPatch.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperationsPatch.
        Name given to the process definition

        :param name: The name of this OperationsPatch.
        :type: str
        """

        self._name = name

    @property
    def logo_url(self):
        """
        Gets the logo_url of this OperationsPatch.
        URL to a logo image

        :return: The logo_url of this OperationsPatch.
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """
        Sets the logo_url of this OperationsPatch.
        URL to a logo image

        :param logo_url: The logo_url of this OperationsPatch.
        :type: str
        """

        self._logo_url = logo_url

    @property
    def description(self):
        """
        Gets the description of this OperationsPatch.
        Textual description of the semantics of the process

        :return: The description of this OperationsPatch.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OperationsPatch.
        Textual description of the semantics of the process

        :param description: The description of this OperationsPatch.
        :type: str
        """

        self._description = description

    @property
    def string_parameters(self):
        """
        Gets the string_parameters of this OperationsPatch.
        JSON-formatted array (treated as a set) giving the list of string parameters of the process

        :return: The string_parameters of this OperationsPatch.
        :rtype: str
        """
        return self._string_parameters

    @string_parameters.setter
    def string_parameters(self, string_parameters):
        """
        Sets the string_parameters of this OperationsPatch.
        JSON-formatted array (treated as a set) giving the list of string parameters of the process

        :param string_parameters: The string_parameters of this OperationsPatch.
        :type: str
        """

        self._string_parameters = string_parameters

    @property
    def file_parameters(self):
        """
        Gets the file_parameters of this OperationsPatch.
        JSON-formatted array (treated as a set) giving the list of file parameters of the process

        :return: The file_parameters of this OperationsPatch.
        :rtype: str
        """
        return self._file_parameters

    @file_parameters.setter
    def file_parameters(self, file_parameters):
        """
        Sets the file_parameters of this OperationsPatch.
        JSON-formatted array (treated as a set) giving the list of file parameters of the process

        :param file_parameters: The file_parameters of this OperationsPatch.
        :type: str
        """

        self._file_parameters = file_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
